# Firepup650
Package containing various shorthand things I use, and a few imports I almost always use
#### Change log:
###### v.1.0.4:
Subscript errors
###### v.1.0.3:
Dependant errors
###### v.1.0.2:
Random shorthand (litterally)
###### v.1.0.1:
Added animated typing function, sleep shorthand
###### v.1.0.0:
Initial Release!